import datetime
import typing

import kubernetes.client

class V1beta1EndpointConditions:
    ready: typing.Optional[bool]
    def __init__(self, *, ready: typing.Optional[bool] = ...) -> None: ...
    def to_dict(self) -> V1beta1EndpointConditionsDict: ...

class V1beta1EndpointConditionsDict(typing.TypedDict, total=False):
    ready: typing.Optional[bool]



import datetime
import typing

import kubernetes.client

class V1CrossVersionObjectReference:
    api_version: typing.Optional[str]
    kind: str
    name: str
    def __init__(
        self, *, api_version: typing.Optional[str] = ..., kind: str, name: str
    ) -> None: ...
    def to_dict(self) -> V1CrossVersionObjectReferenceDict: ...

class V1CrossVersionObjectReferenceDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: str
    name: str



import datetime
import typing

import kubernetes.client

class V1ComponentStatus:
    api_version: typing.Optional[str]
    conditions: typing.Optional[list[kubernetes.client.V1ComponentCondition]]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        conditions: typing.Optional[list[kubernetes.client.V1ComponentCondition]] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...
    ) -> None: ...
    def to_dict(self) -> V1ComponentStatusDict: ...

class V1ComponentStatusDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    conditions: typing.Optional[list[kubernetes.client.V1ComponentConditionDict]]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]



import datetime
import typing

import kubernetes.client

class V1alpha1PodPresetSpec:
    env: typing.Optional[list[kubernetes.client.V1EnvVar]]
    env_from: typing.Optional[list[kubernetes.client.V1EnvFromSource]]
    selector: typing.Optional[kubernetes.client.V1LabelSelector]
    volume_mounts: typing.Optional[list[kubernetes.client.V1VolumeMount]]
    volumes: typing.Optional[list[kubernetes.client.V1Volume]]
    def __init__(
        self,
        *,
        env: typing.Optional[list[kubernetes.client.V1EnvVar]] = ...,
        env_from: typing.Optional[list[kubernetes.client.V1EnvFromSource]] = ...,
        selector: typing.Optional[kubernetes.client.V1LabelSelector] = ...,
        volume_mounts: typing.Optional[list[kubernetes.client.V1VolumeMount]] = ...,
        volumes: typing.Optional[list[kubernetes.client.V1Volume]] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1PodPresetSpecDict: ...

class V1alpha1PodPresetSpecDict(typing.TypedDict, total=False):
    env: typing.Optional[list[kubernetes.client.V1EnvVarDict]]
    envFrom: typing.Optional[list[kubernetes.client.V1EnvFromSourceDict]]
    selector: typing.Optional[kubernetes.client.V1LabelSelectorDict]
    volumeMounts: typing.Optional[list[kubernetes.client.V1VolumeMountDict]]
    volumes: typing.Optional[list[kubernetes.client.V1VolumeDict]]



import datetime
import typing

import kubernetes.client

class ExtensionsV1beta1Ingress:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressSpec]
    status: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressStatus]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressSpec] = ...,
        status: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressStatus] = ...
    ) -> None: ...
    def to_dict(self) -> ExtensionsV1beta1IngressDict: ...

class ExtensionsV1beta1IngressDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressSpecDict]
    status: typing.Optional[kubernetes.client.ExtensionsV1beta1IngressStatusDict]



import datetime
import typing

import kubernetes.client

class V1alpha1PodPreset:
    api_version: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMeta]
    spec: typing.Optional[kubernetes.client.V1alpha1PodPresetSpec]
    def __init__(
        self,
        *,
        api_version: typing.Optional[str] = ...,
        kind: typing.Optional[str] = ...,
        metadata: typing.Optional[kubernetes.client.V1ObjectMeta] = ...,
        spec: typing.Optional[kubernetes.client.V1alpha1PodPresetSpec] = ...
    ) -> None: ...
    def to_dict(self) -> V1alpha1PodPresetDict: ...

class V1alpha1PodPresetDict(typing.TypedDict, total=False):
    apiVersion: typing.Optional[str]
    kind: typing.Optional[str]
    metadata: typing.Optional[kubernetes.client.V1ObjectMetaDict]
    spec: typing.Optional[kubernetes.client.V1alpha1PodPresetSpecDict]



import datetime
import typing

import kubernetes.client

class V1RBDPersistentVolumeSource:
    fs_type: typing.Optional[str]
    image: str
    keyring: typing.Optional[str]
    monitors: list[str]
    pool: typing.Optional[str]
    read_only: typing.Optional[bool]
    secret_ref: typing.Optional[kubernetes.client.V1SecretReference]
    user: typing.Optional[str]
    def __init__(
        self,
        *,
        fs_type: typing.Optional[str] = ...,
        image: str,
        keyring: typing.Optional[str] = ...,
        monitors: list[str],
        pool: typing.Optional[str] = ...,
        read_only: typing.Optional[bool] = ...,
        secret_ref: typing.Optional[kubernetes.client.V1SecretReference] = ...,
        user: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1RBDPersistentVolumeSourceDict: ...

class V1RBDPersistentVolumeSourceDict(typing.TypedDict, total=False):
    fsType: typing.Optional[str]
    image: str
    keyring: typing.Optional[str]
    monitors: list[str]
    pool: typing.Optional[str]
    readOnly: typing.Optional[bool]
    secretRef: typing.Optional[kubernetes.client.V1SecretReferenceDict]
    user: typing.Optional[str]



import datetime
import typing

import kubernetes.client

class V1LoadBalancerIngress:
    hostname: typing.Optional[str]
    ip: typing.Optional[str]
    def __init__(
        self, *, hostname: typing.Optional[str] = ..., ip: typing.Optional[str] = ...
    ) -> None: ...
    def to_dict(self) -> V1LoadBalancerIngressDict: ...

class V1LoadBalancerIngressDict(typing.TypedDict, total=False):
    hostname: typing.Optional[str]
    ip: typing.Optional[str]
